@@ -30,14 +30,14 @@ abstract class AsymmetricKey
     /**
      * Precomputed Zero
      *
-     * @var \phpseclib3\Math\BigInteger
+     * @var BigInteger
      */
     protected static $zero;
 
     /**
      * Precomputed One
      *
-     * @var \phpseclib3\Math\BigInteger
+     * @var BigInteger
      */
     protected static $one;
 
@@ -51,14 +51,14 @@ abstract class AsymmetricKey
     /**
      * Hash function
      *
-     * @var \phpseclib3\Crypt\Hash
+     * @var Hash
      */
     protected $hash;
 
     /**
      * HMAC function
      *
-     * @var \phpseclib3\Crypt\Hash
+     * @var Hash
      */
     private $hmac;
 
@@ -94,7 +94,7 @@ abstract class AsymmetricKey
 
     /**
      * @param string $type
-     * @return string
+     * @return array|string
      */
     abstract public function toString($type, array $options = []);
 
@@ -130,7 +130,7 @@ abstract class AsymmetricKey
      *
      * @param string $key
      * @param string $password optional
-     * @return AsymmetricKey
+     * @return PublicKey|PrivateKey
      */
     public static function load($key, $password = false)
     {
@@ -382,7 +382,7 @@ abstract class AsymmetricKey
             $shortname = $meta->getShortName();
             self::$plugins[static::ALGORITHM]['Keys'][strtolower($shortname)] = $fullname;
             if ($meta->hasConstant('IS_INVISIBLE')) {
-                self::$invisiblePlugins[static::ALGORITHM] = strtolower($name);
+                self::$invisiblePlugins[static::ALGORITHM][] = strtolower($shortname);
             }
         }
     }
@@ -531,7 +531,7 @@ abstract class AsymmetricKey
     /**
      * Integer to Octet String
      *
-     * @param \phpseclib3\Math\BigInteger $v
+     * @param BigInteger $v
      * @return string
      */
     private function int2octets($v)
@@ -551,7 +551,7 @@ abstract class AsymmetricKey
      * Bit String to Integer
      *
      * @param string $in
-     * @return \phpseclib3\Math\BigInteger
+     * @return BigInteger
      */
     protected function bits2int($in)
     {
