@@ -542,4 +542,13 @@ E252896950917476ECE5E8FC27D5F053D6018D91B502C4787558A002B9283DA7', 16);
 
         $this->assertSame('9', (string) $d);
     }
+
+    /**
+     * @group github2113
+     */
+    public function testPHP85ChrDeprecation()
+    {
+        $a = $this->getInstance('999999999');
+        $this->assertSame('3b9ac9ff', $a->toHex());
+    }
 }
